import random
from webcolors import name_to_rgb, CSS3_NAMES_TO_HEX


def generate_color_shades(color_name, rgb=False):
  """Generates a list of 20 shades of a specified color."""
  try:
    color_rgb = name_to_rgb(color_name)
    color_shades = []
    for i in range(20):
      shade = []
      for j in range(3):
        c = int(color_rgb[j] + (255 - color_rgb[j]) * (i / 20))
        shade.append(c)
      color_shades.append(tuple(shade))
    if rgb:
      return color_shades
    else:
      hex_color_shades = []
      for shade in color_shades:
        hex_shade = '#'
        for c in shade:
          hex_shade += hex(c)[2:].zfill(2)
        hex_color_shades.append(hex_shade)
      return hex_color_shades
  except ValueError:
    if color_name not in CSS3_NAMES_TO_HEX:
      raise ValueError(f"{color_name} is not a valid color name.")



from setuptools import setup
with open("readme.md", "r") as fh:
  long_description = fh.read()

setup(
  name='python-colorcode',
  version='0.2',
  author='Anshu Pal',
  author_email='anshupal257@gmail.com',
  packages=['python-colorcode'],
  description="A Python package for generating shades of a color",
  long_description=long_description,
  long_description_content_type="text/markdown",
  classifiers=[
    "Programming Language :: Python :: 3",
    "License :: OSI Approved :: MIT License",
    "Operating System :: OS Independent",
  ],
  python_requires='>=3.6',
  install_requires=[
    'webcolors',
  ],
)
